#
# This make file is maintained by the user
#
# It should only be necessary to change two things:
# 1) to add a new routine, add it to the object list
# 2) add any include files to the include list.
#
# example:
#  I add routine user_new.f containing an include statement for
#  hec_datacard.inc. To compile it, add user_new.o to the list of 
#  objects (after user_ter.o)
#  and add hec_datacard.inc to the list of includes (after 
#  user_common.inc).
#
#
# VPATH sets where to look for include files (besides the current
# directory)
#
VPATH=../inc
#
# list of objects and include files
#
OBJECTS = user_ana1.o user_ana2.o user_ana3.o user_card.o \
          user_evt1.o user_evt2.o user_evt3.o \
          user_ini.o user_ini1.o user_ini2.o user_ini3.o \
          user_ter.o user_search.o
#
INC     = user_common.inc
#
# user should not need to change anything below this point.
# CHANGE BELOW THIS POINT AT YOUR OWN RISK
#
#
# now figure out compiler and options for this platform
#
PLATFORM=$(shell uname)
#
# HP Unix
#
ifeq "$(PLATFORM)" "HP-UX"
  LIB = -L/cern/pro/lib -lpawlib -lgraflib -lgrafX11 \
        -lpacklib -lkernlib -lmathlib -lm -lX11
  COMP         = fort77 -c +ppu  -O2 -I../inc
  LINK         = fort77 +ppu -O2
  LIB_NAME     = hec_adc.a
  OS_EXTENTION = 
endif
#
# IBM (AIX) operating system 4.1 
#
ifeq "$(PLATFORM)" "AIX"                  
  LIB       = `cernlib geant321 pawlib graflib grafX11 packlib genlib kernlib`
  COMP         = xlf -O2 -u -qextname -qcharlen=32767 -qrndsngl -c \
                     -qobj -qnolist -qrecur -I../inc
  LINK         = xlf -O2
  LIB_NAME     = hec_adc_AIX.a
  OS_EXTENTION = 
endif
#
# DEC ALPHA OSF 3.2 (use OS_EXTENTION only in version 3.2)
#
ifeq "$(PLATFORM)" "OSF1"
  LIB        = `cernlib geant321 pawlib graflib grafX11 packlib genlib kernlib'
  COMP         = f77 -c -C -O2 -I../inc
  LINK         = f77 -C -O2
  LIB_NAME     = hec_adc_ALPHA.a
#  OS_EXTENTION = -lm_4sqrt
  OS_EXTENTION = 
endif
#
# PC Linux
#
ifeq "$(PLATFORM)" "Linux"
  LIB   = `cernlib pawlib graflib grafX11 packlib genlib kernlib`
  COMP  = g77 -c -I../inc
  LINK  = g77
  LIB_NAME = linux_lib/*.o
endif
#
# compile 
#
hec_adc : $(OBJECTS) ../$(LIBNAME)
	$(LINK) *.o ../$(LIB_NAME) -o hec_adc $(LIB) $(OS_EXTENTION)
#
# define how to make an object from a .f file
#
.f.o :
	$(COMP) $<
#
# objects depend on the include files
#
$(OBJECTS) : $(INC)
